summaryrefslogtreecommitdiffstats
path: root/libk9copy/dvdprogress.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit5660db4e68c904cc2dd01888775483189cda7a10 (patch)
treef8bb487ab12519611d3ddca1839a03396e954c77 /libk9copy/dvdprogress.cpp
parent33e6166f7e62c479bad5d46ad240ea9704f848fd (diff)
downloadk9copy-5660db4e68c904cc2dd01888775483189cda7a10.tar.gz
k9copy-5660db4e68c904cc2dd01888775483189cda7a10.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/k9copy@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libk9copy/dvdprogress.cpp')
-rw-r--r--libk9copy/dvdprogress.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/libk9copy/dvdprogress.cpp b/libk9copy/dvdprogress.cpp
index 83e37a5..3c85363 100644
--- a/libk9copy/dvdprogress.cpp
+++ b/libk9copy/dvdprogress.cpp
@@ -18,14 +18,14 @@
#include <tqwhatsthis.h>
/*
* Constructs a DVDProgress as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*
* The dialog will by default be modeless, unless you set 'modal' to
* TRUE to construct a modal dialog.
*/
-DVDProgress::DVDProgress( TQWidget* tqparent, const char* name, bool modal, WFlags fl )
- : TQDialog( tqparent, name, modal, fl )
+DVDProgress::DVDProgress( TQWidget* parent, const char* name, bool modal, WFlags fl )
+ : TQDialog( parent, name, modal, fl )
{
if ( !name )
setName( "DVDProgress" );
@@ -18,14 +18,14 @@
#include <tqwhatsthis.h>
/*
- * Constructs a DVDProgress as a child of 'tqparent', with the
+ * Constructs a DVDProgress as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*